pub struct FakeNetcfgSetDnsRequest {
pub servers: Vec<DnsServer_>,
}Fields
servers: Vec<DnsServer_>Trait Implementations
Sourceimpl Clone for FakeNetcfgSetDnsRequest
impl Clone for FakeNetcfgSetDnsRequest
Sourcefn clone(&self) -> FakeNetcfgSetDnsRequest
fn clone(&self) -> FakeNetcfgSetDnsRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FakeNetcfgSetDnsRequest
impl Debug for FakeNetcfgSetDnsRequest
Sourceimpl<D> Decode<FakeNetcfgSetDnsRequest, D> for FakeNetcfgSetDnsRequestwhere
D: ResourceDialect,
impl<D> Decode<FakeNetcfgSetDnsRequest, D> for FakeNetcfgSetDnsRequestwhere
D: ResourceDialect,
Sourcefn new_empty() -> FakeNetcfgSetDnsRequest
fn new_empty() -> FakeNetcfgSetDnsRequest
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl<D> Encode<FakeNetcfgSetDnsRequest, D> for &FakeNetcfgSetDnsRequestwhere
D: ResourceDialect,
impl<D> Encode<FakeNetcfgSetDnsRequest, D> for &FakeNetcfgSetDnsRequestwhere
D: ResourceDialect,
Sourceimpl PartialEq for FakeNetcfgSetDnsRequest
impl PartialEq for FakeNetcfgSetDnsRequest
Sourceimpl TypeMarker for FakeNetcfgSetDnsRequest
impl TypeMarker for FakeNetcfgSetDnsRequest
Sourcetype Owned = FakeNetcfgSetDnsRequest
type Owned = FakeNetcfgSetDnsRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for FakeNetcfgSetDnsRequest
impl ValueTypeMarker for FakeNetcfgSetDnsRequest
Sourcetype Borrowed<'a> = &'a FakeNetcfgSetDnsRequest
type Borrowed<'a> = &'a FakeNetcfgSetDnsRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<FakeNetcfgSetDnsRequest as TypeMarker>::Owned,
) -> <FakeNetcfgSetDnsRequest as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<FakeNetcfgSetDnsRequest as TypeMarker>::Owned, ) -> <FakeNetcfgSetDnsRequest as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.impl Persistable for FakeNetcfgSetDnsRequest
impl StructuralPartialEq for FakeNetcfgSetDnsRequest